@@ -17,16 +17,17 @@ extern crate alloc;
 use alloc::vec::Vec;
 
 pub use crate::iterators::*;
+pub use crate::trait_impls::*;
 use crate::utils::*;
 use core::cmp::{Ord, PartialEq};
-use core::iter::FromIterator;
 use core::marker::PhantomData;
 use core::mem::MaybeUninit;
-use core::ops::{Bound::Excluded, Bound::Included, Bound::Unbounded, Index, IndexMut, RangeBounds};
+use core::ops::{Bound::Excluded, Bound::Included, Bound::Unbounded, RangeBounds};
 use core::ptr;
 
 mod iterators;
 mod macros;
+mod trait_impls;
 #[doc(hidden)]
 pub mod utils;
 
@@ -213,7 +214,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
   ///Asserts that `index` is less than the current length of the StaticVec,
   ///and if so removes the value at that position and returns it. Any values
   ///that exist in later positions are shifted to the left.
-  #[inline(always)]
+  #[inline]
   pub fn remove(&mut self, index: usize) -> T {
     assert!(index < self.length);
     unsafe {
@@ -521,121 +522,3 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     self.dedup_by(|a, b| key(a) == key(b))
   }
 }
-
-impl<T, const N: usize> Default for StaticVec<T, {N}> {
-  ///Calls `new`.
-  #[inline(always)]
-  fn default() -> Self {
-    Self::new()
-  }
-}
-
-impl<T, const N: usize> Drop for StaticVec<T, {N}> {
-  ///Calls `clear` through the StaticVec before dropping it.
-  #[inline(always)]
-  fn drop(&mut self) {
-    self.clear();
-  }
-}
-
-impl<T, const N: usize> Extend<T> for StaticVec<T, {N}> {
-  ///Appends all elements, if any, from `iter` to the StaticVec. If `iter` has a size greater than
-  ///the StaticVec's capacity, any items after that point are ignored.
-  #[inline]
-  fn extend<I: IntoIterator<Item = T>>(&mut self, iter: I) {
-    let mut it = iter.into_iter();
-    let iter_length = it.size_hint().0;
-    if iter_length > 0 {
-      let new_length = (self.length + iter_length).min(N);
-      for i in self.length..new_length {
-        unsafe {
-          self.data.get_unchecked_mut(i).write(it.next().unwrap());
-        }
-      }
-      self.length = new_length;
-    } else {
-      for i in self.length..N {
-        if let Some(val) = it.next() {
-          unsafe {
-            self.data.get_unchecked_mut(i).write(val);
-          }
-        } else {
-          self.length = i;
-        }
-      }
-    }
-  }
-}
-
-impl<T: Copy, const N: usize> From<&[T]> for StaticVec<T, {N}> {
-  ///Creates a new StaticVec instance from the contents of `values`, using
-  ///[new_from_slice](crate::StaticVec::new_from_slice) internally.
-  #[inline(always)]
-  fn from(values: &[T]) -> Self {
-    Self::new_from_slice(values)
-  }
-}
-
-impl<T, const N: usize> FromIterator<T> for StaticVec<T, {N}> {
-  ///Creates a new StaticVec instance from the elements, if any, of `iter`.
-  ///If `iter` has a size greater than the StaticVec's capacity, any items after
-  ///that point are ignored.
-  #[inline]
-  fn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self {
-    let mut res = Self::new();
-    let mut it = iter.into_iter();
-    for i in 0..N {
-      if let Some(val) = it.next() {
-        unsafe {
-          res.data.get_unchecked_mut(i).write(val);
-        }
-      } else {
-        res.length = i;
-        return res;
-      }
-    }
-    res.length = N;
-    res
-  }
-}
-
-impl<T, const N: usize> Index<usize> for StaticVec<T, {N}> {
-  type Output = T;
-  ///Asserts that `index` is less than the current length of the StaticVec,
-  ///and if so returns the value at that position as a constant reference.
-  #[inline(always)]
-  fn index(&self, index: usize) -> &Self::Output {
-    assert!(index < self.length);
-    unsafe { self.data.get_unchecked(index).get_ref() }
-  }
-}
-
-impl<T, const N: usize> IndexMut<usize> for StaticVec<T, {N}> {
-  ///Asserts that `index` is less than the current length of the StaticVec,
-  ///and if so returns the value at that position as a mutable reference.
-  #[inline(always)]
-  fn index_mut(&mut self, index: usize) -> &mut Self::Output {
-    assert!(index < self.length);
-    unsafe { self.data.get_unchecked_mut(index).get_mut() }
-  }
-}
-
-impl<'a, T: 'a, const N: usize> IntoIterator for &'a StaticVec<T, {N}> {
-  type IntoIter = StaticVecIterConst<'a, T>;
-  type Item = <Self::IntoIter as Iterator>::Item;
-  ///Returns a `StaticVecIterConst` over the StaticVec's inhabited area.
-  #[inline(always)]
-  fn into_iter(self) -> Self::IntoIter {
-    self.iter()
-  }
-}
-
-impl<'a, T: 'a, const N: usize> IntoIterator for &'a mut StaticVec<T, {N}> {
-  type IntoIter = StaticVecIterMut<'a, T>;
-  type Item = <Self::IntoIter as Iterator>::Item;
-  ///Returns a `StaticVecIterMut` over the StaticVec's inhabited area.
-  #[inline(always)]
-  fn into_iter(self) -> Self::IntoIter {
-    self.iter_mut()
-  }
-}
